"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GerritService = void 0;
const lodash_1 = __importDefault(require("lodash"));
const gerrit_api_1 = require("./gerrit.api");
const CHANGE_ID_KEYWORD = 'change-id:';
class GerritService {
    constructor(inputs) {
        this.gerritApi = new gerrit_api_1.GerritApi(inputs);
        this.inputs = inputs;
    }
    static parseChangeId(gerritChangeId) {
        if (!gerritChangeId) {
            throw new Error('Gerrit changeId is not set');
        }
        if (gerritChangeId.toLowerCase().includes(CHANGE_ID_KEYWORD)) {
            const regexpResult = new RegExp('(?<=Change-Id:).*', 'i').exec(gerritChangeId);
            if (!lodash_1.default.isArray(regexpResult) || !lodash_1.default.isEmpty(regexpResult)) {
                throw new Error('Not found changeId');
            }
            return lodash_1.default.get(regexpResult, '[0]', '').replace(/\s/g, '');
        }
        return gerritChangeId;
    }
    async getPullRequestsWithCommits(repo, changeId) {
        try {
            const change = await this.gerritApi.getChange(changeId, repo);
            const info = await this.gerritApi.getCommitsInfo(change);
            const result = {
                ...info,
                prDate: change.updated || change.created,
                number: change._number,
                url: `${this.inputs.gerritHost}/c/${repo}/+/${change._number}`,
                title: change.subject,
                targetBranch: change.branch
            };
            return [result];
        }
        catch (error) {
            throw new Error(`failed to get pull requests: ${error.message}`);
        }
    }
    async getBranch(repo, changeId) {
        const gerritChangeInfo = await this.gerritApi.getChange(changeId, repo);
        if (!gerritChangeInfo) {
            return null;
        }
        const currentRevision = gerritChangeInfo?.revisions[gerritChangeInfo?.current_revision];
        return {
            name: gerritChangeInfo.branch,
            commit: currentRevision.commit.message,
            commitMsg: currentRevision.commit.message,
            commitURL: `${this.inputs.gerritHost}${currentRevision.commit.web_links[0].url}`,
            committerUsername: currentRevision.commit.committer.name || currentRevision.commit.committer.email
        };
    }
}
exports.GerritService = GerritService;
//# sourceMappingURL=gerrit.service.js.map