import _ from 'lodash'

import { GithubService } from './github'
import { BitbucketService } from './bitbucket'
import { BitbucketServerService } from './bitbucket-server'
import { GitlabService } from './gitlab'
import { GerritService } from './gerrit'

export const providers = {
    GITHUB: 'github',
    BITBUCKET: 'bitbucket',
    BITBUCKET_SERVER: 'bitbucket-server',
    GERRIT: 'gerrit',
    GITLAB: 'gitlab'
}

export class GitProviders {

    static get(provider) {
        switch (provider) {
            case providers.GITHUB:
                return GithubService
            case providers.BITBUCKET:
                return BitbucketService
            case providers.BITBUCKET_SERVER:
                return BitbucketServerService
            case providers.GITLAB:
                return GitlabService
            case providers.GERRIT:
                return GerritService
            default:
                throw new Error(`Provider ${provider} is not supported`)
        }
    }

    static getTheMostRecentCommit(prs, revision) {
        // If we have revision sha return this commit
        if (revision) {
            for (const pr of prs) {
                for (const commit of pr.commits) {
                    if (commit.sha === revision) {
                        return commit
                    }
                }
            }
        }

        // Otherwise return the last commit of the last PR
        const prsSortedByDateAsc = prs.sort((pr1, pr2) => {
            return new Date(pr1.prDate).getTime() - new Date(pr2.prDate).getTime()
        })
        const recentPR = _.last<any>(prsSortedByDateAsc)

        const prCommitsSortedByDateAsc = recentPR.commits.sort((c1, c2) => {
            return new Date(c1.commitDate).getTime() - new Date(c2.commitDate).getTime()
        })
        return _.last<any>(prCommitsSortedByDateAsc)
    }
}
